@@ -1,18 +1,18 @@
 /*
-   SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "gravatarresolvurljob.h"
+#include "gravatar_debug.h"
 #include "misc/gravatarcache.h"
 #include "misc/hash.h"
-#include "gravatar_debug.h"
 #include <PimCommon/NetworkManager>
 
 #include <QCryptographicHash>
-#include <QUrlQuery>
 #include <QNetworkConfigurationManager>
+#include <QUrlQuery>
 
 using namespace Gravatar;
 
@@ -29,11 +29,7 @@ public:
     QNetworkAccessManager *mNetworkAccessManager = nullptr;
     int mSize = 80;
 
-    enum Backend {
-        None = 0x0,
-        Libravatar = 0x1,
-        Gravatar = 0x2
-    };
+    enum Backend { None = 0x0, Libravatar = 0x1, Gravatar = 0x2 };
     int mBackends = Gravatar;
 
     bool mHasGravatar = false;
@@ -54,7 +50,7 @@ GravatarResolvUrlJob::~GravatarResolvUrlJob()
 bool GravatarResolvUrlJob::canStart() const
 {
     if (PimCommon::NetworkManager::self()->networkConfigureManager()->isOnline()) {
-        //qCDebug(GRAVATAR_LOG) << "email " << d->mEmail;
+        // qCDebug(GRAVATAR_LOG) << "email " << d->mEmail;
         return !d->mEmail.trimmed().isEmpty() && (d->mEmail.contains(QLatin1Char('@')));
     } else {
         return false;
@@ -79,16 +75,11 @@ void GravatarResolvUrlJob::startNetworkManager(const QUrl &url)
         d->mNetworkAccessManager->setStrictTransportSecurityEnabled(true);
         d->mNetworkAccessManager->enableStrictTransportSecurityStore(true);
         connect(d->mNetworkAccessManager, &QNetworkAccessManager::finished, this, &GravatarResolvUrlJob::slotFinishLoadPixmap);
-
     }
 
     QNetworkRequest req(url);
     req.setAttribute(QNetworkRequest::HttpPipeliningAllowedAttribute, true);
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-    req.setAttribute(QNetworkRequest::HTTP2AllowedAttribute, true);
-#else
     req.setAttribute(QNetworkRequest::Http2AllowedAttribute, true);
-#endif
     d->mNetworkAccessManager->get(req);
 }
 
@@ -124,7 +115,7 @@ void GravatarResolvUrlJob::processNextBackend()
         url = createUrl(false);
     }
 
-    //qDebug() << " url " << url;
+    // qDebug() << " url " << url;
     Q_EMIT resolvUrl(url);
     if (!cacheLookup(d->mCalculatedHash)) {
         startNetworkManager(url);
@@ -139,7 +130,7 @@ void GravatarResolvUrlJob::slotFinishLoadPixmap(QNetworkReply *reply)
         const QByteArray data = reply->readAll();
         d->mPixmap.loadFromData(data);
         d->mHasGravatar = true;
-        //For the moment don't use cache other we will store a lot of pixmap
+        // For the moment don't use cache other we will store a lot of pixmap
         if (!d->mUseDefaultPixmap) {
             GravatarCache::self()->saveGravatarPixmap(d->mCalculatedHash, d->mPixmap);
         }
@@ -241,7 +232,7 @@ QUrl GravatarResolvUrlJob::createUrl(bool useLibravatar)
     }
     QUrlQuery query;
     if (!d->mUseDefaultPixmap) {
-        //Add ?d=404
+        // Add ?d=404
         query.addQueryItem(QStringLiteral("d"), QStringLiteral("404"));
     }
     if (d->mSize != 80) {
