@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -7,10 +7,11 @@
 #ifndef GRAVATARDOWNLOADPIXMAPDIALOG_H
 #define GRAVATARDOWNLOADPIXMAPDIALOG_H
 
-#include <QDialog>
 #include "gravatar_export.h"
+#include <QDialog>
 
-namespace Gravatar {
+namespace Gravatar
+{
 class GravatarDownloadPixmapWidget;
 
 /** Avatar download dialog. */
